#!/usr/bin/env julia
#
# @license Apache-2.0
#
# Copyright (c) 2018 The Stdlib Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import JSON

"""
    gen( x, name )

Generate fixture data and write to file.

# Arguments

* `x`: domain
* `name::AbstractString`: output filename

# Examples

``` julia
julia> x = range( 0, stop = 4294967295, length = 1000 );
julia> gen( x, \"data.json\" );
```
"""
function gen( x, name )
	y = Array{UInt32}( undef, length(x) );
	z = Array{Int32}( undef, length(x) );
	for i in eachindex(x)
		v = trunc( x[i] );
		v = convert( UInt32, v );
		y[ i ] = v;

		# Mimic modulo behavior found in JavaScript...
		if v > 2147483647
			v = v - 4294967296;
		end
		z[ i ] = convert( Int32, v );
	end

	# Store data to be written to file as a collection:
	data = Dict([
		("x", y),
		("expected", z)
	]);

	# Based on the script directory, create an output filepath:
	filepath = joinpath( dir, name );

	# Write the data to the output filepath as JSON:
	outfile = open( filepath, "w" );
	write( outfile, JSON.json(data) );
	close( outfile );
end

# Get the filename:
file = @__FILE__;

# Extract the directory in which this file resides:
dir = dirname( file );

# Test values:
x = range( 0, stop = 4294967295, length = 1000 );
gen( x, "data.json" );
